# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.web_asyncs_metadata_api import WebAsyncsMetadataApi


class TestWebAsyncsMetadataApi(unittest.TestCase):
    """WebAsyncsMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebAsyncsMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_get2(self) -> None:
        """Test case for get2

        Get by id
        """
        pass

    def test_list(self) -> None:
        """Test case for list

        List
        """
        pass


if __name__ == '__main__':
    unittest.main()
